# eric7.Plugins.DocumentationPlugins.Ericapi.EricapiConfigDialog

Module implementing a dialog to enter the parameters for eric7_api.

### Global Attributes

None

### Classes

EricapiConfigDialog | Class implementing a dialog to enter the parameters for eric7_api.

### Functions

None

## EricapiConfigDialog

Class implementing a dialog to enter the parameters for eric7_api.

### Derived from

QDialog, Ui_EricapiConfigDialog

### Class Attributes

None

### Class Methods

None

### Methods

EricapiConfigDialog | Constructor
__initializeDefaults | Private method to set the default values.
accept | Public slot called by the Ok button.
generateParameters | Public method that generates the command line parameters.
on_addButton_clicked | Private slot to add the directory displayed to the listview.
on_deleteButton_clicked | Private slot to delete the currently selected directory of the listbox.
on_ignoreDirPicker_pathSelected | Private slot handling the selection of a directory to be ignored.
on_outputFilePicker_aboutToShowPathPickerDialog | Private slot called before the file selection dialog is shown.
on_outputFilePicker_pathSelected | Private slot handling the selection of an output file.
on_outputFilePicker_textChanged | Private slot to enable/disable the "OK" button.
on_startDirPicker_pathSelected | Private slot handling the selection of a start directory.

### Static Methods

None

#### EricapiConfigDialog (Constructor)

EricapiConfigDialog(project, parms=None, parent=None)

Constructor

project
  reference to the project object (Project.Project)
parms
  parameters to set in the dialog
parent
  parent widget of this dialog

#### EricapiConfigDialog.__initializeDefaults

__initializeDefaults()

Private method to set the default values.

These are needed later on to generate the commandline parameters.

#### EricapiConfigDialog.accept

accept()

Public slot called by the Ok button.

It saves the values in the parameters dictionary.

#### EricapiConfigDialog.generateParameters

generateParameters()

Public method that generates the command line parameters.

It generates a list of strings to be used to set the QProcess arguments for the ericapi call and a dictionary containing the non default parameters. This dictionary can be passed back upon object generation to overwrite the default settings.

Return:
  a tuple containing the commandline parameters, non default parameters and the start directory

Return Type:
  tuple of (list of str, dict, str)

#### EricapiConfigDialog.on_addButton_clicked

on_addButton_clicked()

Private slot to add the directory displayed to the listview.

The directory in the ignore directories line edit is moved to the listbox above and the edit is cleared.

#### EricapiConfigDialog.on_deleteButton_clicked

on_deleteButton_clicked()

Private slot to delete the currently selected directory of the listbox.

#### EricapiConfigDialog.on_ignoreDirPicker_pathSelected

on_ignoreDirPicker_pathSelected(path)

Private slot handling the selection of a directory to be ignored.

path (str)
  path of the directory to be ignored

#### EricapiConfigDialog.on_outputFilePicker_aboutToShowPathPickerDialog

on_outputFilePicker_aboutToShowPathPickerDialog()

Private slot called before the file selection dialog is shown.

#### EricapiConfigDialog.on_outputFilePicker_pathSelected

on_outputFilePicker_pathSelected(path)

Private slot handling the selection of an output file.

path (str)
  path of the output file

#### EricapiConfigDialog.on_outputFilePicker_textChanged

on_outputFilePicker_textChanged(filename)

Private slot to enable/disable the "OK" button.

filename
  name of the file (string)

#### EricapiConfigDialog.on_startDirPicker_pathSelected

on_startDirPicker_pathSelected(path)

Private slot handling the selection of a start directory.

path (str)
  path of the start directory

Up